@@ -33,6 +33,11 @@
 #include <term.h>
 #define HAVE_CURSES
 #else
+#ifdef HAVE_NCURSES_CURSES
+#include <ncurses/curses.h>
+#include <ncurses/term.h>
+#define HAVE_CURSES
+#else
 #ifdef HAVE_CURSES
 #include <curses.h>
 #include <term.h>
@@ -42,6 +47,7 @@
 #endif
 #endif
 #endif
+#endif
 
 #ifdef VTE_DEBUG
 static const char *
